@@ -34,7 +34,7 @@
 #'   }
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' library(bootStateSpace)
 #' # prepare parameters
 #' ## number of individuals
@@ -193,5 +193,5 @@ BootIndirectCentral <- function(phi,
     "ctmedboot",
     class(out)
   )
-  return(out)
+  out
 }
