@@ -50,7 +50,7 @@
 #'   }
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' library(bootStateSpace)
 #' # prepare parameters
 #' ## number of individuals
@@ -216,9 +216,7 @@ BootMed <- function(phi,
     X = med,
     FUN = function(x,
                    idx) {
-      return(
-        which(idx == x)
-      )
+      which(idx == x)
     },
     idx = idx
   )
@@ -242,5 +240,5 @@ BootMed <- function(phi,
     "ctmedboot",
     class(out)
   )
-  return(out)
+  out
 }
