@@ -304,5 +304,5 @@ DeltaBetaStd <- function(phi,
     "ctmeddelta",
     class(out)
   )
-  return(out)
+  out
 }
