@@ -291,5 +291,5 @@ DeltaTotalCentral <- function(phi,
     "ctmeddelta",
     class(out)
   )
-  return(out)
+  out
 }
