@@ -232,9 +232,7 @@ Direct <- function(phi,
       X = med,
       FUN = function(x,
                      idx) {
-        return(
-          which(idx == x)
-        )
+        which(idx == x)
       },
       idx = idx
     )
@@ -249,5 +247,5 @@ Direct <- function(phi,
     "ctmedeffect",
     class(out)
   )
-  return(out)
+  out
 }
