@@ -36,12 +36,10 @@
       phis <- parallel::mclapply(
         X = seq_len(R),
         FUN = function(i) {
-          return(
-            .MCPhiI(
-              phi = phi,
-              vcov_phi_vec_l = t(chol(vcov_phi_vec)),
-              test_phi = test_phi
-            )
+          .MCPhiI(
+            phi = phi,
+            vcov_phi_vec_l = t(chol(vcov_phi_vec)),
+            test_phi = test_phi
           )
         },
         mc.cores = ncores
@@ -81,12 +79,11 @@
             "indirect",
             "interval"
           )
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     } else {
@@ -105,12 +102,10 @@
         cl = cl,
         X = seq_len(R),
         fun = function(i) {
-          return(
-            .MCPhiI(
-              phi = phi,
-              vcov_phi_vec_l = t(chol(vcov_phi_vec)),
-              test_phi = test_phi
-            )
+          .MCPhiI(
+            phi = phi,
+            vcov_phi_vec_l = t(chol(vcov_phi_vec)),
+            test_phi = test_phi
           )
         }
       )
@@ -149,12 +144,11 @@
             "indirect",
             "interval"
           )
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     }
@@ -167,12 +161,10 @@
     phis <- lapply(
       X = seq_len(R),
       FUN = function(i) {
-        return(
-          .MCPhiI(
-            phi = phi,
-            vcov_phi_vec_l = t(chol(vcov_phi_vec)),
-            test_phi = test_phi
-          )
+        .MCPhiI(
+          phi = phi,
+          vcov_phi_vec_l = t(chol(vcov_phi_vec)),
+          test_phi = test_phi
         )
       }
     )
@@ -210,14 +202,13 @@
           "indirect",
           "interval"
         )
-        out <- list(
+        list(
           delta_t = i,
           est = est,
           thetahatstar = thetahatstar
         )
-        return(out)
       }
     )
   }
-  return(output)
+  output
 }
