@@ -148,5 +148,5 @@ PosteriorBeta <- function(phi,
     "ctmedmc",
     class(out)
   )
-  return(out)
+  out
 }
