@@ -174,9 +174,7 @@ PosteriorMed <- function(phi,
     X = med,
     FUN = function(x,
                    idx) {
-      return(
-        which(idx == x)
-      )
+      which(idx == x)
     },
     idx = idx
   )
@@ -199,5 +197,5 @@ PosteriorMed <- function(phi,
     "ctmedmc",
     class(out)
   )
-  return(out)
+  out
 }
